# Welcome to binance-asyncio

This is an unofficial wrapper for the Binance API, as per the license, its provided with no guarantee, so use it at your own risk.

## Current status

This is very much work-in-process, currently, this library offer fairly good coverage of the web-sockets, and terrible coverage for everything else.

## Quick start

Install with  

```
python -m venv /path/to/virtual-environment
source /path/to/virtual-environment/bin/activate
```

``pip install binance-asyncio``


If you cloned this repository and want to run the examples 
``python -m examples.get_klines``
